@@ -30,6 +30,11 @@ from Iuppiter.DjangoUtil import (extendInstalledApps,
 from oscar import get_core_apps
 from oscar import OSCAR_MAIN_TEMPLATE_DIR
 
+oscarDefaultsPackages = __import__(
+    'oscar.defaults', globals(), locals(), [], -1).__dict__
+
+from django.utils.translation import ugettext_lazy as _
+
 def attachSettings(settingsDict, enablePaypal=False):
     """
     Attach default settings to settings.py.
@@ -68,12 +73,12 @@ def attachSettings(settingsDict, enablePaypal=False):
     emailDefaults = {
         'ACCOUNT_EMAIL_CONFIRMATION_REQUIRED' : True,
         'EMAIL_BACKEND' : 'django.core.mail.backends.smtp.EmailBackend',
-        'OSCAR_FROM_EMAIL' : settingsDict['DEFAULT_FROM_EMAIL']
     }
     
     warnWithout('EMAIL_BACKEND', settingsDict, emailDefaults)
 
     update(settingsDict, emailDefaults)
+    settingsDict['OSCAR_FROM_EMAIL'] = settingsDict['DEFAULT_FROM_EMAIL']
     #=========================================================================
     
     #=========================================================================
@@ -126,6 +131,20 @@ def attachSettings(settingsDict, enablePaypal=False):
     update(settingsDict, ADDING_HAYSTACK_CONNECTIONS)
     #=========================================================================
 
+    #=========================================================================
+    # Static files setting for Iuno.shop
+    location = lambda x: os.path.join(
+        os.path.dirname(os.path.realpath(settingsDict['__file__'])), x)
+
+    if settingsDict['DEBUG']:
+        STATIC_ROOT = location('static')
+    #=========================================================================
+
+    #=========================================================================
+    for package in oscarDefaultsPackages:
+        update(settingsDict, package)
+    #=========================================================================
+
     #=========================================================================
     if enablePaypal:
         require('PAYPAL_API_USERNAME', settingsDict)
